@@ -16,7 +16,7 @@ use Pod::Usage qw(pod2usage);
 use Try::Tiny qw(try catch);
 use URI::Split qw(uri_split);
 
-our $VERSION = '1.0.5';
+our $VERSION = '1.1.0';
 
 # defaults
 use constant {
@@ -27,7 +27,7 @@ use constant {
     NAME       => 'wax',
     TEMPLATE   => 'XXXXXXXX',
     TIMEOUT    => 60,
-    USER_AGENT => 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:35.0) Gecko/20100101 Firefox/35.0',
+    USER_AGENT => 'Mozilla/5.0 (X11; Linux x86_64; rv:50.0) Gecko/20100101 Firefox/50.0',
     VERBOSE    => 0,
 };
 
@@ -39,6 +39,7 @@ use constant {
     E_NO_ARGUMENTS      => -4,
     E_NO_COMMAND        => -5,
     E_INVALID_OPTION    => -6,
+    E_INVALID_DIRECTORY => -7,
 };
 
 has app_name => (
@@ -59,6 +60,7 @@ has directory => (
     isa       => 'Str',
     predicate => 'has_directory',
     required  => 0,
+    trigger   => \&_check_directory,
 );
 
 has keep => (
@@ -126,6 +128,19 @@ has verbose => (
     trigger => method ($verbose) { $| = 1 }, # unbuffer output
 );
 
+# log the path. if the directory doesn't exist, create it if its parent directory
+# exists; otherwise, raise an error
+method _check_directory ($dir) {
+    $self->debug("directory: $dir");
+
+    unless (-d $dir) {
+        unless (mkdir $dir) {
+            $self->log(ERROR => "Can't create directory (%s): %s", $dir, $!);
+            exit E_INVALID_DIRECTORY;
+        }
+    }
+}
+
 # lazy constructor for the default LWP::UserAgent instance
 method _build_lwp_user_agent {
     LWP::UserAgent->new(
@@ -379,6 +394,10 @@ method run ($argv) {
                 $self->cache(1);
             } elsif ($arg =~ /^(?:-d|--dir|--directory)$/) {
                 $self->directory(shift @argv);
+            } elsif ($arg eq '-D') {
+                # "${XDG_CACHE_HOME:-$HOME/.cache}/wax"
+                require File::BaseDir;
+                $self->directory(File::BaseDir::cache_home(NAME));
             } elsif ($arg =~ /^(?:-v|--verbose)$/) {
                 $self->verbose(1);
             } elsif ($arg =~ /^(?:-[?h]|--help)$/) {
